import { __decorate, __metadata, __param } from 'tslib';
import { Injectable, Inject, NgModule } from '@angular/core';
import { HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { BehaviorSubject } from 'rxjs';
import { lib, PBKDF2, AES, pad, mode, enc } from 'crypto-js';
import 'rxjs/add/operator/map';

var CryptService = /** @class */ (function () {
    function CryptService() {
        this.keySize = 256;
        this.ivSize = 128;
        this.saltSize = 256;
        this.iterations = 1000;
    }
    CryptService.prototype.encrypt = function (msg, pass) {
        var salt = lib.WordArray.random(this.saltSize / 8);
        var key = PBKDF2(pass, salt, {
            keySize: this.keySize / 32,
            iterations: this.iterations
        });
        var iv = lib.WordArray.random(this.ivSize / 8);
        var encrypted = AES.encrypt(msg, key, {
            iv: iv,
            padding: pad.Pkcs7,
            mode: mode.CBC
        });
        var encryptedHex = this.base64ToHex(encrypted.toString());
        var base64result = this.hexToBase64(salt + iv + encryptedHex);
        return base64result;
    };
    CryptService.prototype.decrypt = function (transitmessage, pass) {
        if (transitmessage.toString() === '{}') {
            return JSON.stringify({});
        }
        var hexResult = this.base64ToHex(transitmessage);
        var salt = enc.Hex.parse(hexResult.substr(0, 64));
        var iv = enc.Hex.parse(hexResult.substr(64, 32));
        var encrypted = this.hexToBase64(hexResult.substring(96));
        var key = PBKDF2(pass, salt, {
            keySize: this.keySize / 32,
            iterations: this.iterations
        });
        var decrypted = AES.decrypt(encrypted, key, {
            iv: iv,
            padding: pad.Pkcs7,
            mode: mode.CBC
        });
        return decrypted.toString(enc.Utf8);
    };
    CryptService.prototype.hexToBase64 = function (str) {
        return btoa(String.fromCharCode.apply(null, str.replace(/\r|\n/g, "").replace(/([\da-fA-F]{2}) ?/g, "0x$1 ").replace(/ +$/, "").split(" ")));
    };
    CryptService.prototype.base64ToHex = function (str) {
        for (var i = 0, bin = atob(str.replace(/[ \r\n]+$/, "")), hex = []; i < bin.length; ++i) {
            var tmp = bin.charCodeAt(i).toString(16);
            if (tmp.length === 1)
                tmp = "0" + tmp;
            hex[hex.length] = tmp;
        }
        return hex.join("");
    };
    CryptService = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [])
    ], CryptService);
    return CryptService;
}());

var CryptHttpService = /** @class */ (function () {
    function CryptHttpService(http, crypt) {
        this.http = http;
        this.crypt = crypt;
        this.secret = '';
        this.isOnLoad = new BehaviorSubject(this.running);
    }
    CryptHttpService.prototype.encrypt = function (content) {
        var ciphertext = this.crypt.encrypt(JSON.stringify(content), this.secret);
        return ciphertext;
    };
    CryptHttpService.prototype.decrypt = function (content) {
        if (!this.cryptInactive) {
            if (content.text) {
                content = content.text();
            }
            var bytes = this.crypt.decrypt(content.toString(), this.secret);
            try {
                var decrypted = JSON.parse(bytes);
                this.isOnLoad.next(false);
                return decrypted;
            }
            catch (err) {
                this.isOnLoad.next(false);
                return { error: 'Can not decypted the content' };
            }
        }
        this.isOnLoad.next(false);
        if (!this.warnInactive) {
            this.warn();
        }
        return content;
    };
    CryptHttpService.prototype.setCryptHeaders = function (headers) {
        if (!headers) {
            headers = new HttpHeaders();
        }
        headers = headers.append('Content-Type', 'application/text');
        headers = headers.append('Content-encrypted', 'aes');
        return headers;
    };
    CryptHttpService.prototype.warn = function () {
        console.warn('Warning: You transfer non-encrypted content to the interface. Please check your settings');
    };
    CryptHttpService.prototype.configure = function (options) {
        this.secret = options.secret;
        this.warnInactive = options.warnInactive;
        this.cryptInactive = options.cryptInactive;
    };
    CryptHttpService.prototype.onLoad = function () {
        return this.isOnLoad.asObservable();
    };
    CryptHttpService.prototype.get = function (url, options) {
        var _this = this;
        this.isOnLoad.next(true);
        if (!this.cryptInactive) {
            options.headers = this.setCryptHeaders(options.headers);
            options.responseType = 'text';
        }
        return this.http.get(url, options).map(function (res) { return _this.decrypt(res); }, function (e) { return _this.isOnLoad.next(false); });
    };
    CryptHttpService.prototype.patch = function (url, body, options) {
        var _this = this;
        this.isOnLoad.next(true);
        if (!this.cryptInactive) {
            options.headers = this.setCryptHeaders(options.headers);
            body = this.encrypt(body);
            options.responseType = 'text';
        }
        return this.http.patch(url, body, options).map(function (res) { return _this.decrypt(res); }, function (e) { return _this.isOnLoad.next(false); });
    };
    CryptHttpService.prototype.post = function (url, body, options) {
        var _this = this;
        this.isOnLoad.next(true);
        if (!this.cryptInactive) {
            options.headers = this.setCryptHeaders(options.headers);
            options.responseType = 'text';
            body = this.encrypt(body);
        }
        return this.http.post(url, body, options).map(function (res) { return _this.decrypt(res); }, function (e) { return _this.isOnLoad.next(false); });
    };
    CryptHttpService.prototype.put = function (url, body, options) {
        var _this = this;
        this.isOnLoad.next(true);
        if (!this.cryptInactive) {
            options.headers = this.setCryptHeaders(options.headers);
            body = this.encrypt(body);
            options.responseType = 'text';
        }
        return this.http.put(url, body, options).map(function (res) { return _this.decrypt(res); }, function (e) { return _this.isOnLoad.next(false); });
    };
    CryptHttpService.prototype.delete = function (url, options) {
        var _this = this;
        this.isOnLoad.next(true);
        if (!this.cryptInactive) {
            options.headers = this.setCryptHeaders(options.headers);
            options.responseType = 'text';
        }
        return this.http.delete(url, options).map(function (res) { return _this.decrypt(res); }, function (e) { return _this.isOnLoad.next(false); });
    };
    CryptHttpService.prototype.options = function (url, options) {
        var _this = this;
        this.isOnLoad.next(true);
        if (!this.cryptInactive) {
            options.headers = this.setCryptHeaders(options.headers);
            options.responseType = 'text';
        }
        return this.http.options(url, options).map(function (res) { return _this.decrypt(res); }, function (e) { return _this.isOnLoad.next(false); });
    };
    CryptHttpService = __decorate([
        Injectable(),
        __param(0, Inject(HttpClient)),
        __metadata("design:paramtypes", [HttpClient, CryptService])
    ], CryptHttpService);
    return CryptHttpService;
}());

var NgxHttpCryptModule = /** @class */ (function () {
    function NgxHttpCryptModule() {
    }
    NgxHttpCryptModule = __decorate([
        NgModule({
            imports: [
                HttpClientModule
            ],
            providers: [
                CryptHttpService, CryptService
            ]
        })
    ], NgxHttpCryptModule);
    return NgxHttpCryptModule;
}());

export { CryptHttpService, CryptService, NgxHttpCryptModule };
//# sourceMappingURL=ngx-http-crypt.js.map
